@@ -1,4 +1,3 @@
-
 def html_template():
     return """
 	<!DOCTYPE doctype html>
@@ -189,12 +188,26 @@ def html_template():
                   margin-bottom: 5%;
                 }
                 
+                .archive-card__footer {
+                  display: flex;
+                  flex-direction: row;
+                  justify-content: space-between;
+                  margin-bottom: 5%;
+                  max-width: 60%;
+                  padding-top: 5.5%;
+                  padding-left: 5%;
+                }
+                
                 .card__footer-section {
                   text-align: center;
                   width: 33%;
                   # border-right: 1px solid #ccc;
                 }
                 
+                .archive-card__footer-section {
+                  text-align: center;
+                }
+                
                 .card__footer-section:nth-child(3) {
                   border-right: none;
                 }
@@ -204,12 +217,189 @@ def html_template():
                   font-weight: 900;
                 }
                 
+                .archive-footer-section__data {
+                  font-size: 4.2rem;
+                  font-weight: 700;
+                }
+                
                 .footer-section__label {
                   text-transform: uppercase;
                   color: slategrey;
                   font-size: 1.0rem;
                 }
                 
+                .list-group-item {
+                    border: 5px solid rgba(0,0,0,0);
+                }
+                
+                .list-group {
+                    height: 100%;
+                    background-color: #ffff;
+                    display: flex;
+                    flex-direction: column;
+                    place-self: center;
+                    border-radius: 4px;
+                    box-shadow: 1px 1px 4px rgba(0,0,0,0.4);
+                }
+                
+                .archive-body {
+                    height: 100%;
+                    background-color: #ffff;
+                    max-width: 85%;
+                    border-radius: 4px;
+                    box-shadow: 1px 1px 4px rgba(0,0,0,0.4);
+                    margin-bottom: 0.8%;
+                }
+                
+                .archive-header {
+                    padding-top: 4%;
+                    padding-left: 5%;
+                    color: gray;
+                }
+                
+                .archive-date {
+                    padding-top: 2%;
+                    padding-left: 5%;
+                    color: gray;
+                }
+                
+                .archive-chart-container {
+                    margin-top: 6%;
+                    height: 50%;
+                    width: 50%;
+                    margin-left: 40%;
+                }
+                
+                .statistic-section-pass {
+                     padding-top: 51px;
+                     padding-bottom: 45px;
+                     background: #00c6ff;  /* fallback for old browsers */
+                     background: linear-gradient(to right, #333333, #2b4440);
+                }
+                
+                .statistic-section-fail {
+                     padding-top: 51px;
+                     padding-bottom: 45px;
+                     background: #00c6ff;  /* fallback for old browsers */
+                     background: linear-gradient(to right, #333333, #442b2b);
+                }
+                
+                .count-title {
+                    font-size: 50px;
+                    font-weight: normal;
+                    margin-top: 10px;
+                    margin-bottom: 0;
+                      text-align: center;
+                      font-weight: bold;
+                    color: #fff;
+                }
+                
+                .stats-text {
+                    font-size: 15px;
+                    font-weight: normal;
+                    margin-top: 15px;
+                    margin-bottom: 0;
+                    text-align: center;
+                      color: #fff;
+                      text-transform: uppercase;
+                      font-weight: bold;
+                }
+                
+                .stats-line-black {
+                    margin: 12px auto 0;
+                    width: 55px;
+                    height: 2px;
+                    background-color: #fff;
+                }
+                
+                .stats-icon {
+                      font-size: 35px;
+                      margin: 0 auto;
+                    float: none;
+                    display: table;
+                    color: #fff;
+                }
+                
+                @media (max-width: 992px) {
+                    .counter {
+                        margin-bottom: 40px;
+                    }
+                }
+                
+                .archive-build-row {
+                    right: 0.5%;
+                    width: 200px;
+                    top: 0;
+                    bottom: 0;
+                    position: fixed;
+                    overflow-y: scroll;
+                    overflow-x: hidden;
+                }
+                
+                .loading {
+                    height: 200px;
+                    padding-top: 35px;
+                }
+                
+                .loading p {
+                    font-size: 1.1rem;
+                    padding-top: 5%;
+                    margin: 0px 0 45px;
+                    color: dimgrey;
+                    float: right;
+                }
+                
+                .loading .icon {
+                    padding-right: 15px;
+                }
+                
+                .loading .percentage {
+                    float: right;
+                    padding: 6px 35px 0 0;
+                }
+                
+                .loading .progress-bar {
+                    height: 20px;
+                    background: #50597b;
+                    border-radius: 5px;
+                    margin: 0 auto;
+                    margin-top: -4%;
+                }
+                
+                .progress-bar.downloading {
+                    background: -webkit-linear-gradient(left, #fc6665 __max_failure_percent__%,#50597b __max_failure_percent__%); /* Chrome10+,Safari5.1+ */
+                    background: -ms-linear-gradient(left, #fc6665 __max_failure_percent__%,#50597b __max_failure_percent__%); /* IE10+ */
+                    background: linear-gradient(to right, #fc6665 __max_failure_percent__%,#50597b __max_failure_percent__%); /* W3C */
+                }
+                
+                .arrow {
+                    left: 50%;
+                    color: #403b3b;
+                }
+                
+               .tooltip {
+                    position: relative;
+                    display: inline-block;
+                    margin: 10px 20px;
+                    opacity: 1;
+                }
+                
+                .tooltip-inner {
+                    background-color: #403b3b;
+                }
+                
+                .bs-tooltip-top .arrow::before {
+                    border-top-color: #403b3b;
+                }
+                
+                .suite-highlights-header {
+                    font-size: 0.95rem;
+                    padding-top: 5%;
+                    margin: 0px 0 45px;
+                    color: dimgrey;
+                    float: right;
+                }
+                
             </style>
         </head>
     </html>
@@ -223,8 +413,10 @@ def html_template():
                 <i class="fa fa-briefcase" id="tablinkicon" style="color:currentcolor; margin:5% 5% 5% 10%"></i> Suites</a>
             <a class="tablink" href="#" onclick="openPage('testMetrics', this, 'white', '#565656', 'groove'); executeDataTable('#tm',3)">
                 <i class="fa fa-server" id="tablinkicon" style="color:currentcolor; margin:5% 5% 5% 10%"></i> Test Metrics</a>
+            <a class="tablink" href="#" onclick="openPage('archives', this, 'white', '#565656', 'groove'); executeDataTable('#tm',3)">
+                <i class="fa fa-history" id="tablinkicon" style="color:currentcolor; margin:5% 5% 5% 10%"></i> Archives</a>
         </div>
-        <div class="main col-md-9 ml-sm-auto col-lg-10 px-4">
+        <div class="main col-md-9 ml-sm-auto col-lg-10 px-4" style="height: 100%;">
             <div class="tabcontent" id="dashboard">
                 
                 <div class="row rowcard">
@@ -321,7 +513,23 @@ def html_template():
                     </div>
                     <div class="col-md-4 card border-left" style="max-width: 32.4%; padding-left: 3%; padding-top: 2%; margin-left: 0.75%;">
                         <div style="font-size: 1.9rem; color: darkgrey; margin-bottom: -4%;">
-                            <div style="font-weight: 550;font-family: sans-serif;padding-top: 5%;padding-left: 2%;"><i class="fa fa-bolt" style="color:currentcolor; margin-right: 2%; padding-left: 3%;"></i>Suite Highlights</div>
+                            <div style="font-weight: 550;font-family: sans-serif;padding-top: 5%;padding-left: 2%;">
+                                <i class="fa fa-bolt" style="color:currentcolor; margin-right: 2%; padding-left: 3%;"></i>
+                                Suite Highlights
+                            </div>
+                            <div>
+                                <div class="loading">
+                                    <div style="display: flow-root;">
+                                        <div class="tooltip bs-tooltip-top tooltip-dark" role="tooltip">
+                                           <div class="arrow" style="left: 50%"></div>
+                                           <div class="tooltip-inner">__max_failure_suite_name_final__</div>
+                                        </div>
+                                        <p class="percentage">__max_failure_suite_count__<sup> /__max_failure_total_tests__</sup> Times</p>
+                                    </div>
+                                    <div class="progress-bar downloading"></div>
+                                    <span class="suite-highlights-header">MOST FAILED SUITE</span>
+                                </div>
+                            </div>
                         </div>
                     </div>
                 </div>
@@ -387,6 +595,15 @@ def html_template():
                 <div class="col-md-12" style="height:25px;width:auto;"></div>
             </div>
         </div>
+        <div class="tabcontent" id="archives">
+            <div id="list-example" class="list-group archive-build-row">
+              __archive_status__
+            </div>
+            
+            <div data-spy="scroll" data-target="#list-example" data-offset="0" class="scrollspy-example">
+                __archive_body_content__
+            </div>
+        </div>
         <script>
             function createBarGraph(tableID, keyword_column, time_column, limit, ChartID, Label, type) {
                 var status = [];
@@ -552,6 +769,22 @@ def html_template():
                 document.getElementsByClassName("total__count")[0].style.paddingLeft = `${size}`;
             }
         </script>
+        <script>
+            function archiveTotalCase(total, i) {
+                number = [1, 2, 3, 4, 5];
+                container = ['23%', '20%', '15%', '12%', '7%'];
+                label = ['-24%', '-2%', '15%', '27%', '31%'];
+                
+                zipped = container.map((x, i) => [x, label[i]]);
+                var x = parseInt(total);
+                
+                acontainer = zipped[(x.toString().length)-1][0];
+                alabel = zipped[(x.toString().length)-1][1];
+                
+                document.getElementById(`archive-container-${i}`).style.paddingLeft = `${acontainer}`;
+                document.getElementById(`archive-label-${i}`).style.marginLeft = `${alabel}`;
+            }
+        </script>
         <script>
             function openPage(pageName,elmnt,color,bgcolor,borderstyle) {
                 var i, tabcontent, tablinks;
@@ -650,7 +883,7 @@ def html_template():
                       caretPadding: 13,
                       xPadding: 12,
                       yPadding: 12
-                    }
+                  }
                 }
             });
             
@@ -679,6 +912,65 @@ def html_template():
                 });
         </script>
         
+        <script>
+            for(var i=0; i<=__archive_count__; i++) {
+                var MeSeContext = document.getElementById("archive-chart-"+i).getContext("2d");
+                var archives = __archives__;
+                var pass = archives[i].pass;
+                var fail = archives[i].fail;
+                var skip = archives[i].skip;
+                var xpass = archives[i].xpass;
+                var xfail = archives[i].xfail;
+                var error = archives[i].error;
+                var total = archives[i].total;
+                
+                archiveTotalCase(total, i)
+                
+                var MeSeData = {
+                    labels: ["PASS", "FAIL", "SKIP", "XPASS", "XFAIL", "ERROR"],
+                    datasets: [{
+                        label: "Test",
+                        data: [pass, fail, skip, xpass, xfail, error],
+                        backgroundColor: ["#98cc64", "#fc6766", '#ffd050', '#aaaaaa', '#d35fbf', '#b13635'],
+                        hoverBackgroundColor: ["#84b356", "#e35857", "#e4b942", "#bdbbbb", "#c357b0", '#8b2828'],
+                        hoverBorderColor: ["#9bca6d", "#fd8a89", "#ffcf4c", "#abaaaa", "#f26fdb", "#b13635"]
+                    }]
+                };
+                
+                var MeSeChart = new Chart(MeSeContext, {
+                    type: 'horizontalBar',
+                    data: MeSeData,
+                    options: {
+                        legend: {
+                            display: false
+                        },
+                        responsive: false,
+                        scales: {
+                            yAxes: [{
+                                stacked: true
+                            }]
+                        },
+                        tooltips: {
+                          backgroundColor: '#FFF',
+                          titleFontSize: 10,
+                          titleFontColor: '#555555',
+                          bodyFontColor: '#000',
+                          bodyFontSize: 12,
+                          displayColors: false,
+                          borderColor: '#555555',
+                          borderWidth: 2,
+                          multiKeyBackground: '#555555',
+                          cornerRadius: 2,
+                          caretSize: 5,
+                          caretPadding: 5,
+                          xPadding: 5,
+                          yPadding: 5
+                      }
+                    }
+                });
+            }
+        </script>
+        
         <script>
             var ctx = document.getElementById('groupBarChart').getContext('2d');
             var myChart = new Chart(ctx, {
@@ -772,4 +1064,4 @@ def html_template():
         </script>
         
     </body>
-	"""
\ No newline at end of file
+	"""
